@@ -8,7 +8,7 @@ use List::Util qw( first );
 use Path::Tiny qw( path );
 
 # ABSTRACT: Use Alien::Build with Dist::Zilla
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 
 with 'Dist::Zilla::Role::FileMunger';
@@ -37,11 +37,13 @@ sub register_prereqs
     $alienfile->spew($file->content);
     my $build = Alien::Build->load($alienfile);
 
+    my $ab_version = '0.10';
+
     if($self->_installer eq 'Makefile.PL')
     {
       $self->zilla->register_prereqs(
         { phase => $_ },
-        'Alien::Build::MM' => '0.08',
+        'Alien::Build::MM' => $ab_version,
         'ExtUtils::MakeMaker' => '6.52',
       ) for qw( configure build );
     }
@@ -56,13 +58,14 @@ sub register_prereqs
     # Configure requires...
     $self->zilla->register_prereqs(
       { phase => 'configure' },
+      'Alien::Build' => $ab_version,
       %{ $build->requires('configure') },
     );
     
     # Build requires...
-    $DB::single = 1;
     $self->zilla->register_prereqs(
       { phase => 'build' },
+      'Alien::Build' => $ab_version,
       %{ $build->requires('any') },
     );
   }
@@ -153,7 +156,7 @@ Dist::Zilla::Plugin::AlienBuild - Use Alien::Build with Dist::Zilla
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
